Function position_to_offset
Source pub(crate) fn position_to_offset(
position: Position,
rope: &Rope,
) -> Option<usize>
Convert an LSP Position into a byte offset using a Rope.
Returns None if the position lies past the end of the document.